@@ -8,7 +8,7 @@ class GoodsAction(object):
                 print("find params===>key={0},value={1}".format(i, params[i]))
 
         main = GoodsManager()
-        return main.get(**params)
+        return main.get_test(**params)
 
     def post(self, **params):
         if params:
