@@ -2,7 +2,7 @@ from skyext import EXT_CONTEXT
 from sqlalchemy import Column, Integer, String
 
 
-class Goods(EXT_CONTEXT["db"].Model):
+class Goods(EXT_CONTEXT["db"].Model if EXT_CONTEXT.get("db") else object):
 
     __tablename__ = 'goods'
 
